# liblzss

![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/antoniovazquezblanco/jzp/test.yml)
![PyPI](https://img.shields.io/pypi/v/jzp)

A libary for dealing with the compression and decompression of Agilent JZP files.

I could not find documentation about this propietary format. Researching https://github.com/miek/agltzip I understood that the files consist on various possible versions of a header followed by LZSS compressed files.


## Installing

Install and update using `pip`:

```bash
$ pip install -U jzp
```


## Links

-   PyPI Releases: https://pypi.org/project/jzp/
-   Source Code: https://github.com/antoniovazquezblanco/jzp
-   Issue Tracker: https://github.com/antoniovazquezblanco/jzp/issues
